library(ape)
library(tidytree)
library(dplyr)
library(RColorBrewer)

# load the tree and metadata
supertree <- readRDS("Myco.plant.supertree.output_v3.rds")
fulldata <- read.csv("11770.csv",encoding = "UTF-8")
fulldata <- fulldata[,-1]

# drop tips to the final 11770 species
spmatch <- match(supertree$scenario.3$tip.label,
                 fulldata[,1])
myco.tree <- drop.tip(supertree$scenario.3,
                      supertree$scenario.3$tip.label[is.na(spmatch)])
cbind(myco.tree$tip.label,fulldata[,1])
spmatch <- match(myco.tree$tip.label,
                 fulldata[,1])
data <- fulldata[spmatch,]
all(myco.tree$tip.label == data[,1])
fulldata$mete = 10

# manipulate tree data using tidy interface, see 
# https://yulab-smu.top/treedata-book/chapter2.html?q=full_join#tidytree
# for details
x <- as_tibble(myco.tree)
d <- tibble(label = data$Species,
            family= data$Family,
            Status = data$Mycorrhizal_status,
            Type=data$Mycorrhizal_type)
y <- full_join(x, d, by = 'label')
y  <- y  %>% mutate(Type = ifelse(is.na(Type), 0, Type))
treedata <- as.treedata(y)


type_tab <- fulldata[,c("Species", "Family", "Mycorrhizal_type")]
type_tab <- type_tab %>%
  group_by(Family, Mycorrhizal_type) %>%
  summarise(n = n())
clipr::write_clip(type_tab)
#write.csv(y, "tree_infoY.csv")

# plot the tree
library(ggtree)
library(ggplot2)
library(ggtreeExtra)
library(ggnewscale)

set2_grey <- brewer.pal(8,"Set2")[8]
set2_AM <- brewer.pal(8,"Set2")[5]
set2_ECM <- brewer.pal(8,"Set2")[2]
set2_ERM <- brewer.pal(8,"Set2")[1]
set2_ORM <- brewer.pal(8,"Set2")[6]
set2_NM <- brewer.pal(8,"Set2")[4]
set2_FM <- brewer.pal(8,"Set2")[7]
set2_OM <- brewer.pal(8,"Set2")[3]

fig <- ggtree(treedata, ladderize = F, layout ="circular", color = set2_grey, size = 0.1)
{
fig1 <- fig +
  geom_fruit(
    data = fulldata,
    geom = geom_bar,
    mapping = aes(x = mete, y = Species, fill = Mycorrhizal_status),
    orientation = "y",
    stat = "identity",
    colour = NA,
    pwidth = 0.1,
    offset = 0) +
  scale_fill_manual(values = c(set2_FM, set2_NM, set2_OM),
                    guide = guide_legend(keywidth = 0.5, keyheight = 0.5, order = 1),
                    name = "Mycorrhizal status"
  )

fig2 <- fig1 +
  geom_strip("Viminaria_juncea", "Schotia_afra", label = "Fabaceae", color = 'mediumpurple4', hjust = 0.8, offset.text = 90, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(3759, 3893, color= set2_FM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(3893, 3949, color= set2_NM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(3949, 4807, color= set2_OM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Zinnia_peruviana", "Dasyphyllum_diacanthoides", label = "Asteraceae", color = 'mediumpurple4', hjust = 0.1, offset.text = 90, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(1, 131, color= set2_FM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(131, 163, color= set2_NM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(163, 941, color= set2_OM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Raddiella_esenbeckii", "Ehrharta_stipoides", label="Poaceae", color = 'mediumpurple4', offset.text = 85, hjust = 0.5, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(8856, 9063, color = set2_FM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70.5)+
  geom_strip(9063, 9117, color = set2_NM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(9117, 9625, color = set2_OM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Teesdaliopsis_conferta", "Aethionema_saxatile", label = "Brassicaceae", color = 'mediumpurple4', offset.text = 70, hjust = 1, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(6389, 6477, color = set2_FM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70.5)+
  geom_strip(6477, 6814, color = set2_NM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(6814, 6877, color = set2_OM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Cyathochaeta_avenacea","Hypolytrum_nemorum", label="Cyperaceae", color = 'mediumpurple4', offset.text = 90, hjust = 0.2, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(9654, 9791, color = set2_FM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70.5)+
  geom_strip(9791, 9977, color = set2_NM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(9977, 10067, color = set2_OM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Potentilla_supina", "Rhodotypos_scandens", label = "Rosaceae", color = 'mediumpurple4', offset.text = 80, hjust = 1, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(4840, 4904, color = set2_FM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(4904, 4916, color = set2_NM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(4916, 5179, color = set2_OM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Tepualia_stipularis", "Xanthostemon_chrysanthus", label = "Myrtaceae", color='mediumpurple4', offset.text = 80, hjust = 1, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(7510, 7533, color = set2_FM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(7533, 7538, color = set2_NM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(7538, 7816, color = set2_OM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Prasium_majus", "Vitex_quinata", label = "Lamiaceae", color = 'mediumpurple4', offset.text = 80, hjust = 0, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(1348, 1384, color = set2_FM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(1384, 1394, color = set2_NM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(1394, 1578, color = set2_OM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Fleroya_ledermannii", "Simira_maxonii", label = "Rubiaceae", color = 'mediumpurple4', offset.text = 85, hjust = 0.2, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(2117, 2150, color = set2_FM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(2150, 2165, color = set2_NM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(2165, 2323, color = set2_OM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Woollsia_pungens", "Enkianthus_perulatus", label = "Ericaceae", color = "mediumpurple4", hjust = 0.5, offset.text = 80, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(2647, 2685, color = set2_FM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(2685, 2687, color = set2_NM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(2687, 2846, color = set2_OM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Pseudorchis_albida", "Neuwiedia_veratrifolia", label = "Orchidaceae", color = 'mediumpurple4', offset.text = 90, hjust = 0.5, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(8431, 8438, color = set2_FM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(8438, 8447, color = set2_NM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(8447, 8603, color = set2_OM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Waltheria_indica", "Grewia_biloba", label = "Malvaceae", color = 'mediumpurple4', offset.text = 80, hjust = 0.9, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(6907, 6928, color = set2_FM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(6928, 6937, color = set2_NM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(6937, 7068, color = set2_OM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Rockinghamia_angustifolia", "Neoscortechinia_kingii", label = "Euphorbiaceae", color = 'mediumpurple4', offset.text = 80, hjust = 0.9, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(6085, 6107, color = set2_FM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70.5)+
  geom_strip(6107, 6117, color = set2_NM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(6117, 6241, color = set2_OM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Pinus_rigida", "Cedrus_deodara", label = "Pinaceae", color = 'mediumpurple4', vjust = 'center', offset.text = 70, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(10986, 10991, color = set2_FM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(10991, 11131, color = set2_OM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Ranunculus_kamchaticus", "Coptis_trifolia", label = "Ranunculaceae", color = 'mediumpurple4', offset.text = 70, hjust = 0.9, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(8213, 8239, color = set2_FM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(8239, 8244, color = set2_NM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(8244, 8357, color = set2_OM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  theme(plot.margin=margin(c(0,0,0,0,"cm"))) 

ggsave("status_bar2.tiff", device = "tiff", width = 210, height=150, units="mm", dpi = 300)
}

