library(ape)
library(tidytree)
library(dplyr)
library(RColorBrewer)

# load the tree and metadata
supertree <- readRDS("Myco.plant.supertree.output_v3.rds")
fulldata <- read.csv("11770.csv",encoding = "UTF-8")
fulldata <- fulldata[,-1]

# drop tips to the final 11770 species
spmatch <- match(supertree$scenario.3$tip.label,
                 fulldata[,1])
myco.tree <- drop.tip(supertree$scenario.3,
                      supertree$scenario.3$tip.label[is.na(spmatch)])
cbind(myco.tree$tip.label,fulldata[,1])
spmatch <- match(myco.tree$tip.label,
                 fulldata[,1])
data <- fulldata[spmatch,]
all(myco.tree$tip.label == data[,1])
fulldata$mete = 10

# manipulate tree data using tidy interface, see 
# https://yulab-smu.top/treedata-book/chapter2.html?q=full_join#tidytree
# for details
x <- as_tibble(myco.tree)
d <- tibble(label = data$Species,
            family= data$Family,
            Status = data$Mycorrhizal_status,
            Type=data$Mycorrhizal_type)
y <- full_join(x, d, by = 'label')
y  <- y  %>% mutate(Type = ifelse(is.na(Type), 0, Type))
treedata <- as.treedata(y)


type_tab <- fulldata[,c("Species", "Family", "Mycorrhizal_type")]
type_tab <- type_tab %>%
  group_by(Family, Mycorrhizal_type) %>%
  summarise(n = n())
clipr::write_clip(type_tab)

# plot the tree
library(ggtree)
library(ggplot2)
library(ggtreeExtra)
library(ggnewscale)

set2_grey <- brewer.pal(8,"Set2")[8]
set2_AM <- brewer.pal(8,"Set2")[5]
set2_ECM <- brewer.pal(8,"Set2")[2]
set2_ERM <- brewer.pal(8,"Set2")[1]
set2_ORM <- brewer.pal(8,"Set2")[6]
set2_NM <- brewer.pal(8,"Set2")[4]
set2_FM <- brewer.pal(8,"Set2")[7]
set2_OM <- brewer.pal(8,"Set2")[3]


fig <- ggtree(treedata, ladderize = F, layout ="circular", color = set2_grey, size = 0.1) 
{
fig1 <- fig +
  geom_fruit(
    data = fulldata,
    geom = geom_bar,
    mapping = aes(x = mete, y = Species, fill = Mycorrhizal_type),
    orientation = "y",
    stat = "identity",
    colour = NA,
    pwidth = 0.1,
    offset = 0) +
  scale_fill_manual(values = c(set2_AM, set2_ECM, 
                              set2_ERM, set2_NM, set2_ORM),
                    guide = guide_legend(keywidth = 0.5, keyheight = 0.5, order = 1),
                    name = "Mycorrhizal type"
  )

fig2 <- fig1 +
  geom_strip("Viminaria_juncea", "Schotia_afra", label = "Fabaceae", color = 'mediumpurple4', hjust = 0.8, offset.text = 90, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(3759, 4576, color = set2_AM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(4576, 4751, color = set2_ECM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(4751, 4807, color = set2_NM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Zinnia_peruviana", "Dasyphyllum_diacanthoides",label = "Asteraceae",color = 'mediumpurple4', hjust = 0.1, offset.text = 90, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(1, 838, color = set2_AM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(838, 909, color = set2_ECM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(909, 941, color = set2_NM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Raddiella_esenbeckii", "Ehrharta_stipoides", label="Poaceae", color = 'mediumpurple4', offset.text = 85, hjust = 0.5, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(8856, 9565, color = set2_AM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(9565, 9570, color = set2_ECM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(9570, 9624, color = set2_NM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(9624, 9625, color = set2_ORM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Teesdaliopsis_conferta", "Aethionema_saxatile", label = "Brassicaceae", color = 'mediumpurple4', offset.text = 70, hjust = 1, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(6389, 6539, color = set2_AM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(6539, 6540, color = set2_ECM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(6540, 6877, color = set2_NM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Cyathochaeta_avenacea", "Hypolytrum_nemorum", label="Cyperaceae", color = 'mediumpurple4', offset.text = 90, hjust = 0.2, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(9654, 9878, color = set2_AM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(9878, 9881, color = set2_ECM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(9881, 10067, color = set2_NM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Potentilla_supina", "Rhodotypos_scandens", label = "Rosaceae", color = 'mediumpurple4', offset.text = 80, hjust = 1, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(4840, 5117, color = set2_AM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(5117, 5167, color = set2_ECM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(5167, 5179, color = set2_NM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Tepualia_stipularis", "Xanthostemon_chrysanthus", label = "Myrtaceae", color='mediumpurple4', offset.text = 80, hjust = 1, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(7510 , 7597, color = set2_AM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(7597, 7811, color = set2_ECM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(7811, 7816, color = set2_NM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Prasium_majus", "Vitex_quinata", label = "Lamiaceae", color = 'mediumpurple4', offset.text = 80, hjust = 0, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(1348, 1565, color = set2_AM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(1565, 1568, color = set2_ECM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(1568, 1578, color = set2_NM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Fleroya_ledermannii", "Simira_maxonii", label = "Rubiaceae", color = 'mediumpurple4', offset.text = 85, hjust = 0.2, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(2117, 2301, color = set2_AM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(2301, 2308, color = set2_ECM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(2308, 2323, color = set2_NM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Woollsia_pungens", "Enkianthus_perulatus", label = "Ericaceae", color = "mediumpurple4", hjust = 0.5, offset.text = 80, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(2647, 2667, color = set2_AM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(2667, 2698, color = set2_ECM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(2698, 2844, color = set2_ERM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(2844, 2846, color = set2_NM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Pseudorchis_albida", "Neuwiedia_veratrifolia", label = "Orchidaceae", color = 'mediumpurple4', offset.text = 90, hjust = 0.5, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(8431, 8451, color = set2_AM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(8451, 8460, color = set2_NM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(8460, 8603, color = set2_ORM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Waltheria_indica", "Grewia_biloba", label = "Malvaceae", color = 'mediumpurple4', offset.text = 80, hjust = 0.9, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(6907, 7047, color = set2_AM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(7047, 7059, color = set2_ECM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(7059, 7068, color = set2_NM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Rockinghamia_angustifolia", "Neoscortechinia_kingii", label = "Euphorbiaceae", color = 'mediumpurple4', offset.text = 80, hjust = 0.9, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(6085, 6229, color = set2_AM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(6229, 6231, color = set2_ECM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(6231, 6241, color = set2_NM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Pinus_rigida", "Cedrus_deodara", label = "Pinaceae", color = 'mediumpurple4', vjust = 'center', offset.text = 70, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(10986 , 11131, color = set2_ECM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  
  geom_strip("Ranunculus_kamchaticus", "Coptis_trifolia", label = "Ranunculaceae", color = 'mediumpurple4', offset.text = 70, hjust = 0.9, fontsize = 4, offset = 35, barsize = 0.6)+
  geom_strip(8213, 8351, color = set2_AM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(8351, 8352, color = set2_ECM, hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  geom_strip(8352, 8357, color = set2_NM , hjust = 0.5, fontsize=3, barsize = 3, offset = 70)+
  theme(plot.margin=margin(c(0,0,0,0,"cm"))) 

ggsave("type_bar2.tiff", device = "tiff", width = 210, height=150, units="mm", dpi = 300)
}

